pub trait PropertyAssertion<K = String>: Send + Sync {
// Required method
fn run(&self, actual: &Property<K>) -> Result<(), Error>;
}Expand description
Trait implemented by types that can act as properies for assertion.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<K> PropertyAssertion<K> for &Regex
impl<K> PropertyAssertion<K> for &Regex
Sourceimpl<K> PropertyAssertion<K> for &str
impl<K> PropertyAssertion<K> for &str
Sourceimpl<K> PropertyAssertion<K> for ExponentialHistogram<f64>
impl<K> PropertyAssertion<K> for ExponentialHistogram<f64>
Sourceimpl<K> PropertyAssertion<K> for ExponentialHistogram<i64>
impl<K> PropertyAssertion<K> for ExponentialHistogram<i64>
Sourceimpl<K> PropertyAssertion<K> for ExponentialHistogram<u64>
impl<K> PropertyAssertion<K> for ExponentialHistogram<u64>
Sourceimpl<K> PropertyAssertion<K> for LinearHistogram<f64>
impl<K> PropertyAssertion<K> for LinearHistogram<f64>
Sourceimpl<K> PropertyAssertion<K> for LinearHistogram<i64>
impl<K> PropertyAssertion<K> for LinearHistogram<i64>
Sourceimpl<K> PropertyAssertion<K> for LinearHistogram<u64>
impl<K> PropertyAssertion<K> for LinearHistogram<u64>
Sourceimpl<K> PropertyAssertion<K> for Regex
A PropertyAssertion that passes for any String containing
a matching for the given regular expression.
impl<K> PropertyAssertion<K> for Regex
A PropertyAssertion that passes for any String containing a matching for the given regular expression.
Sourceimpl<K> PropertyAssertion<K> for String
impl<K> PropertyAssertion<K> for String
Sourceimpl<K> PropertyAssertion<K> for Vec<&str>
impl<K> PropertyAssertion<K> for Vec<&str>
Sourceimpl<K> PropertyAssertion<K> for Vec<String>
impl<K> PropertyAssertion<K> for Vec<String>
Sourceimpl<K> PropertyAssertion<K> for Vec<f64>
Asserts plain numeric arrays
impl<K> PropertyAssertion<K> for Vec<f64>
Asserts plain numeric arrays
Sourceimpl<K> PropertyAssertion<K> for Vec<i64>
Asserts plain numeric arrays
impl<K> PropertyAssertion<K> for Vec<i64>
Asserts plain numeric arrays
Sourceimpl<K> PropertyAssertion<K> for Vec<u8>
impl<K> PropertyAssertion<K> for Vec<u8>
Sourceimpl<K> PropertyAssertion<K> for Vec<u64>
Asserts plain numeric arrays
impl<K> PropertyAssertion<K> for Vec<u64>
Asserts plain numeric arrays
Sourceimpl<K> PropertyAssertion<K> for bool
impl<K> PropertyAssertion<K> for bool
Sourceimpl<K> PropertyAssertion<K> for f32
impl<K> PropertyAssertion<K> for f32
Sourceimpl<K> PropertyAssertion<K> for f64
impl<K> PropertyAssertion<K> for f64
Sourceimpl<K> PropertyAssertion<K> for i8
impl<K> PropertyAssertion<K> for i8
Sourceimpl<K> PropertyAssertion<K> for i16
impl<K> PropertyAssertion<K> for i16
Sourceimpl<K> PropertyAssertion<K> for i32
impl<K> PropertyAssertion<K> for i32
Sourceimpl<K> PropertyAssertion<K> for i64
impl<K> PropertyAssertion<K> for i64
Sourceimpl<K> PropertyAssertion<K> for u8
impl<K> PropertyAssertion<K> for u8
Sourceimpl<K> PropertyAssertion<K> for u16
impl<K> PropertyAssertion<K> for u16
Sourceimpl<K> PropertyAssertion<K> for u32
impl<K> PropertyAssertion<K> for u32
Sourceimpl<K> PropertyAssertion<K> for u64
impl<K> PropertyAssertion<K> for u64
Implementors
impl<K> PropertyAssertion<K> for AnyBoolProperty
impl<K> PropertyAssertion<K> for AnyBytesProperty
impl<K> PropertyAssertion<K> for AnyDoubleProperty
impl<K> PropertyAssertion<K> for AnyIntProperty
impl<K> PropertyAssertion<K> for AnyNumericProperty
impl<K> PropertyAssertion<K> for AnyProperty
impl<K> PropertyAssertion<K> for AnyStringProperty
impl<K> PropertyAssertion<K> for AnyUintProperty
impl<K> PropertyAssertion<K> for HistogramAssertion<f64>
Asserts a histogram.
impl<K> PropertyAssertion<K> for HistogramAssertion<i64>
Asserts a histogram.
impl<K> PropertyAssertion<K> for HistogramAssertion<u64>
Asserts a histogram.